@@ -150,7 +150,7 @@ class TUI(urwid.Frame):
 
         def _default_error_callback(ex):
             self.exception = ex
-            self.footer.set_error_message("An exeption occured, press E to view")
+            self.footer.set_error_message("An exception occurred, press E to view")
 
         _error_callback = error_callback or _default_error_callback
 
@@ -305,7 +305,7 @@ class TUI(urwid.Frame):
 
         def _done(instance):
             if "max_toot_chars" in instance:
-                self.max_toot_chars
+                self.max_toot_chars = instance["max_toot_chars"]
 
         return self.run_in_thread(_load_instance, done_callback=_done)
 
